package com.danitheskunk.skunkgame;

import com.danitheskunk.skunkworks.Recti;
import com.danitheskunk.skunkworks.Vec2i;
import com.danitheskunk.skunkworks.gfx.vt.Terminal;

import java.util.concurrent.Callable;

public class Button {
	private final Vec2i pos;
	private static final Vec2i SIZE = new Vec2i(32, 3);
	private final Recti rect;
	private final String label;
	private int count;
	private Runnable clickCallback;

	public Button(Vec2i pos, String label) {
		this.pos = pos;
		this.label = label;
		this.rect = new Recti(pos, SIZE);
		this.count = 0;
	}

	public void render(Terminal term) {
		var str = label;
		if(count > 0) {
			str = String.format("%s (%d)", label, count);
		}
		boolean hover = rect.contains(SkunkGame.mousePos);
		if(hover) {
			term.drawBoxDouble(rect);
		} else {
			term.drawBoxSingle(rect);
		}
		var off = (rect.getWidth() - str.length()) / 2;
		term.drawString(Vec2i.add(rect.getPos(), new Vec2i(off, 1)), str);
	}

	public void onClick(Runnable callback) {
		clickCallback = callback;
	}

	public void processClick(Vec2i pos) {
		if(rect.contains(pos) && clickCallback != null) {
			clickCallback.run();
		}
	}

	public void setCount(int count) {
		this.count = count;
	}
}
