package com.danitheskunk.skunkgame;

import com.danitheskunk.skunkworks.BaseGame;
import com.danitheskunk.skunkworks.Recti;
import com.danitheskunk.skunkworks.Vec2i;
import com.danitheskunk.skunkworks.WindowStretchMode;
import com.danitheskunk.skunkworks.gfx.Color;
import com.danitheskunk.skunkworks.gfx.IRenderContext;
import com.danitheskunk.skunkworks.gfx.vt.Terminal;

import java.util.ArrayList;
import java.util.List;

public class SkunkGame extends BaseGame {
	private Terminal term;
	private double timeSinceLastUpdate;
	private double timePerUpdate;
	private Resources res;
	public static Vec2i mousePos;
	private List<Button> buttons;

	public SkunkGame() {
		super(new Vec2i(1280, 700), "SkunkGame v0.0.0");
		window.setStretchMode(WindowStretchMode.ASPECT);
		var font = window.loadFontTileset("fonts\\ega-8x14.png");
		term = new Terminal(new Vec2i(160, 50), font);
		res = new Resources();
		timePerUpdate = 1.0;
		buttons = new ArrayList<>();

		var woodButton = new Button(new Vec2i(31, 0), "Gather Wood");
		woodButton.onClick(() -> res.wood += 1.0);
		buttons.add(woodButton);

		var denButton = new Button(new Vec2i(31, 4), "Den");
		denButton.onClick(() -> {
			if(res.wood >= 10.0) {
				res.wood -= 10.0;
				res.den += 1;
				denButton.setCount(res.den);
			}
		});
		buttons.add(denButton);
	}

	private void drawScreen() {
		term.clear(Color.BLACK);
		drawResources();
		term.drawVerticalSingleLine(new Vec2i(30, 0), term.getSize().getY());
		for(var button : buttons) {
			button.render(term);
		}
	}

	private void drawResources() {
		term.drawString(new Vec2i(0, 0), "Wood:");
		term.drawString(
			new Vec2i(18, 0),
			String.format("%d", (int) res.wood)
		);
	}

	private void tick() {

	}

	@Override
	protected void render(IRenderContext rc) {
		drawScreen();
		rc.drawTerminal(term);
	}

	@Override
	protected void update(double delta) {
		timeSinceLastUpdate -= delta;
		if(timeSinceLastUpdate <= 0.0) {
			tick();
			timeSinceLastUpdate += timePerUpdate;
		}
		mousePos = Vec2i.div(window.getMousePos(), term.getFullCharSize());
		if(window.isMouseClicked(0)) {
			for(var button : buttons) {
				button.processClick(mousePos);
			}
		}
	}

	public static void main(String[] args) {
		System.out.println("Hello world <3");
		new SkunkGame().run();
	}
}
